==> orangehrm-3.3.2.txz: usr/local/www/orangehrm/symfony/plugins/orangehrmPerformanceTrackerPlugin/test/model/service/PerformanceTrackerServiceTest.php <==
<?php
/**
 * OrangeHRM is a comprehensive Human Resource Management (HRM) System that captures
 * all the essential functionalities required for any enterprise.
 * Copyright (C) 2006 OrangeHRM Inc., http://www.orangehrm.com
 *
 * OrangeHRM is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * OrangeHRM is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program;
 * if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

/**
 * @group PerformanceTracker
 */
class PerformanceTrackerServiceTest extends PHPUnit_Framework_TestCase {

    private $testCase;
    private $performanceTrackerDao;
    private $performanceTrackerService;
    private $fixture;

    /**
     * Set up method
     */
    protected function setUp() {
        $this->testCase = sfYaml::load(sfConfig::get('sf_plugins_dir') . '/orangehrmPimPlugin/test/fixtures/employee.yml');
        $this->fixture = sfConfig::get('sf_plugins_dir') . '/orangehrmPimPlugin/test/fixtures/EmployeeDao.yml';
        $this->performanceTrackerService = new PerformanceTrackerService();
    }
    
    public function testGetSetPerformanceTrackerDao() {
        $mockDao = $this->getMock('PerformanceTrackerDao');
        
        $this->performanceTrackerService->setPerformanceTrackDao($mockDao);
        $this->assertEquals($mockDao, $this->performanceTrackerService->getPerformanceTrackDao());

    }
    
    
}

==> orangehrm-4.7.txz: usr/local/www/orangehrm/symfony/plugins/orangehrmPerformanceTrackerPlugin/test/model/service/PerformanceTrackerServiceTest.php <==
<?php
/**
 * OrangeHRM is a comprehensive Human Resource Management (HRM) System that captures
 * all the essential functionalities required for any enterprise.
 * Copyright (C) 2006 OrangeHRM Inc., http://www.orangehrm.com
 *
 * OrangeHRM is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * OrangeHRM is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program;
 * if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

/**
 * @group PerformanceTracker
 */
class PerformanceTrackerServiceTest extends PHPUnit_Framework_TestCase {

    private $testCase;
    private $performanceTrackerDao;
    private $performanceTrackerService;
    private $fixture;

    /**
     * Set up method
     */
    protected function setUp() {
        $this->testCase = sfYaml::load(sfConfig::get('sf_plugins_dir') . '/orangehrmPimPlugin/test/fixtures/employee.yml');
        $this->fixture = sfConfig::get('sf_plugins_dir') . '/orangehrmPimPlugin/test/fixtures/EmployeeDao.yml';
        $this->performanceTrackerService = new PerformanceTrackerService();
    }
    
    public function testGetSetPerformanceTrackerDao() {
        $mockDao = $this->getMockBuilder('PerformanceTrackerDao')->getMock();
        
        $this->performanceTrackerService->setPerformanceTrackDao($mockDao);
        $this->assertEquals($mockDao, $this->performanceTrackerService->getPerformanceTrackDao());

    }
    
    
}
